# tree-sitter-css

[![crates][crates]](https://crates.io/crates/tree-sitter-rust-orchard)
[![pypi][pypi]](https://pypi.org/project/tree-sitter-rust-orchard)


CSS grammar for [tree-sitter](https://github.com/tree-sitter/tree-sitter), forked from [tree-sitter-css](https://github.com/tree-sitter/tree-sitter-css).

Note that unlike upstream, generated files are not checked into git, so you need to run `tree-sitter generate` after cloning this repository, or download generate files from the releases page.

Contributions are welcome, so are co-maintainers.

[crates]: https://img.shields.io/crates/v/tree-sitter-css-orchard?logo=rust
[pypi]: https://img.shields.io/pypi/v/tree-sitter-css-orchard?logo=pypi&logoColor=ffd242

